@@ -1,3 +1,3 @@
     Mac OS X            	   2                                              ATTR            D                     *  $com.apple.metadata:_kMDItemUserTags          com.dropbox.attrs    bplist00                            	
 
-vaB      qK	
\ No newline at end of file
+vaB      ĵ	
\ No newline at end of file
