@@ -1,3 +1,3 @@
     Mac OS X            	   2                                              ATTR            D                     *  $com.apple.metadata:_kMDItemUserTags          com.dropbox.attrs    bplist00                            	
 
-vaB      s
\ No newline at end of file
+vaB      䛣
\ No newline at end of file
