@@ -77,8 +77,6 @@ c Write only passed arguments
 c
       real       ldott2  !time rate of change of inductance at t=i-1
       real       lt1     !total inductance at t=i-1/2
-c
-      character buffer*80
 c
 c ----------------------------------------------------------------------
 c
@@ -181,6 +179,11 @@ c
       lt3       = parms(25)
 
       testimpl  = parms(26)
+
+c
+c Initialize
+c
+      radt1 = 0.0
 c
 c ----------------------------------------------------------------------
 c
@@ -492,23 +495,16 @@ c
 
 c write to screen
 
-        write(buffer,'(A)')
+        write(6,'(A)')
      &  ' ------------------------------------------------'
-        call writebuffer(buffer)
-        write(buffer,'(A)')
+        write(6,'(A)')
      &  ' DPF radius has reached the minimum value.'
-        call writebuffer(buffer)
-        write(buffer,'(A,1pe10.3)') '  time:                   ',time
-        call writebuffer(buffer)
-        write(buffer,'(A,1pe10.3)') '  minimum radius:         ',radt1
-        call writebuffer(buffer)
-        write(buffer,'(A,1pe10.3)') '  KE at min-radius:       ',gaske
-        call writebuffer(buffer)
-        write(buffer,'(A,1pe10.3)') '  velocity at min-radius: ',velrt1
-        call writebuffer(buffer)
-        write(buffer,'(A)')
+        write(6,'(A,1pe10.3)') '  time:                   ',time
+        write(6,'(A,1pe10.3)') '  minimum radius:         ',radt1
+        write(6,'(A,1pe10.3)') '  KE at min-radius:       ',gaske
+        write(6,'(A,1pe10.3)') '  velocity at min-radius: ',velrt1
+        write(6,'(A)')
      &  ' ------------------------------------------------'
-        call writebuffer(buffer)
       end if
 c
 c   h. Save all values required for next time step. All of the t1
