@@ -252,7 +252,7 @@ c
         value = savev + fiin (node, branch, time_flag) * dt
         savev = value
 c
-c Generic output from blocks.
+c Generic electrical output from blocks.
 c
       else if (vtype .eq. ip_vout) then
         value = fvblk (node, branch, time_flag)
@@ -343,10 +343,11 @@ c
       else if (vtype .eq. ip_xmfi) then
         value = var_model(11,invarl(inumout))
 c
-c Toms sw parameters not available above.
+c Toms sw parameter, channel radius not available above.
 c
       else if (vtype .eq. ip_fc) then
-        value = var_model(8,invarl(inumout))
+c        value = var_model(8,invarl(inumout))
+        value = radch1
 c
 c Gas puff implosion parameters not available above.
 c Values passed through common block FIPARM.
