@@ -22,6 +22,7 @@ c                 subroutine. Defined internal variables.
 c 2016-04-16 RBS: Added the DPF Model
 c 2016-06-25 RBS: Added the ebeam model
 c 2017-01-02 RBS: Added time-domain skin depth variable resistor model
+c 2020-01-22 RBS: Added cold conductor model RCOND
 c ----------------------------------------------------------------------
 c
 c Include files
@@ -33,7 +34,7 @@ c
       include 'zdemcomm.h'
       include 'zdemvars.h'
 c
-c Define internal variables
+c Declare internal variables
 c
       real
      & anodecurrent, blockvoltage, ccath, cplas,
@@ -458,6 +459,27 @@ c
             call rskin (ht, timehalf, current, var_model(1,ivar),
      &                  max_skin_points, delta_i(1,ivar), H_field, rvar)
             rr(inode,ibranch)    = rvar
+
+c
+c-----------------------------------------------------------------------
+c
+c RCOND Conductor heating Model,  January 1, 2020  RBS
+c Valid for R1, R2 only
+c
+          else if (imodel .eq. rcond_model) then
+c     Get values for current and rvar from the prior time step
+            current = zir(inode,ibranch)
+            rvar    = rr(inode,ibranch)
+
+            call rcond (ht, timehalf, current, var_model(1,ivar), rvar)
+
+c            write(6,*) 'Element type = ', ielement
+
+            if (ielement .eq. r1_var) then
+               g(inode,ibranch)  = 1.0 / (rvar+1.0e-20)
+            else if (ielement .eq. r2_var) then
+               rr(inode,ibranch) = rvar
+            end if
 c
 c-----------------------------------------------------------------------
 c E beam diode model.
