@@ -21,10 +21,11 @@ c    2019-01-28 RBS: Changed the version to 4.3.2
 c    2019-04-23 RBS: Changed the version to 4.3.3
 c    2019-11-25 RBS: Changed the version to 4.4
 c    2019-12-08 RBS: Changed the version to 4.4.1
+c    2020-02-19 RBS; Changed the version to 4.4.2
 c
 c Character strings for SCREAMER version.
 c Edit this string as version changes
 c
       character*(*) screamer_version
       parameter (screamer_version =
-     & 'SCREAMER v4.4.1_beta')
+     & 'SCREAMER v4.4.2')
