@@ -3,13 +3,13 @@ c    @(#)zdemcomm.h   version 1.2   created 02/16/99 09:46:07
 c    Last modified:   19-Jan-1999 13:54:50   klf 
 C_Groups @(#)
 c----------------------------------------------------------------------
-c *****************************************************************************
+c **********************************************************************
 c  This is the common block used for entering data into zdem when using
 c  read_screamer_data  To get this into the program, use include 'zdemcomm.h'
-c *****************************************************************************
+c **********************************************************************
 c  file zdemcomm.h    
 c
-c -----------------------------------------------------------------------
+c ----------------------------------------------------------------------
 c  Modified:
 c 1994-07-03 KWS: Added pointer variables for finding
 c                   variable element parameters.
@@ -25,7 +25,7 @@ c 2015-06-22 RBS: iswitch defined in integer but not placed in common -
 c                 added to common
 c 2017-01-02 RBS: Added dcurr, H_field for skin depth routine
 c 2018-07-20 RBS: Add itabnum in integer declaration and in common.
-c -----------------------------------------------------------------------
+c ----------------------------------------------------------------------
 c
 c Input arrays
 c
@@ -96,7 +96,8 @@ c
      & nsteps, plot_grid, maxfpts, echoset, detail_prints,
      & invarl, inumout
 c
-c Initial energy in inductors and capacitors due to initial current or voltage.
+c Initial energy in inductors and capacitors due
+c to initial current or voltage.
 c
       real              ecapsource, eindsource
       common /einitial/ ecapsource, eindsource
