@@ -19,6 +19,8 @@ c 2014-05-05 RBS: Changed integer*4 to integer
 c 2014-05-07 RBS: All integer variables explicitly defined
 c 2016-04-02 RBS: Reordered all integer parameters
 c 2018-02-22 RBS: Added a new output CLOSS to the MITL outputs
+c 2019-01-27 RBS: Added two parameters: halfstep and scale
+c 2019-04-05 RBS: Added TXT parameter
 c
 c ---------------------------------------------------------------------
       integer    pkeyword_len
@@ -35,7 +37,8 @@ c
      & k_idrpts,
      & k_pffpts,
      & k_csvpts,
-     & k_sfcpts
+     & k_sfcpts,
+     & k_txtpts
 
       parameter (k_pltpts = 'PLO')
       parameter (k_prtpts = 'PRI')
@@ -46,10 +49,11 @@ c
       parameter (k_pffpts = 'PFF')
       parameter (k_csvpts = 'CSV')
       parameter (k_sfcpts = 'SFC')
+      parameter (k_txtpts = 'TXT')
 
       integer
      & ip_pltpts, ip_prtpts, ip_filpts, ip_tabpts, ip_ufopts, ip_idrpts,
-     & ip_pffpts, ip_csvpts, ip_sfcpts
+     & ip_pffpts, ip_csvpts, ip_sfcpts, ip_txtpts
 
       parameter (ip_pltpts = 1)
       parameter (ip_prtpts = 2)
@@ -60,9 +64,10 @@ c
       parameter (ip_pffpts = 7)
       parameter (ip_csvpts = 8)
       parameter (ip_sfcpts = 9)
+      parameter (ip_txtpts = 10)
 c
       integer
-     & oplot, oprint, ofile, otable, oidr, oufo, opff, ocsv, osfc
+     & oplot, oprint, ofile, otable, oidr, oufo, opff, ocsv, osfc, otxt
 c
       parameter (oplot  = 1)
       parameter (oprint = 2)
@@ -73,10 +78,14 @@ c
       parameter (opff   = 7)
       parameter (ocsv   = 8)
       parameter (osfc   = 9)
+      parameter (otxt   = 10)
 c
       character*(pkeyword_len)
-     & k_wholestep
+     & k_wholestep, k_halfstep, k_scale
+
       parameter (k_wholestep = 'WHO')
+      parameter (k_halfstep = 'HAL')
+      parameter (k_scale = 'SCA')
 c
 c ***** Keywords and indicies for PI, RCG, RLS,
 c                                          source resistor outputs *****
